summaryrefslogtreecommitdiff
path: root/perl_exp.SH
diff options
context:
space:
mode:
Diffstat (limited to 'perl_exp.SH')
-rwxr-xr-xperl_exp.SH74
1 files changed, 53 insertions, 21 deletions
diff --git a/perl_exp.SH b/perl_exp.SH
index 49e8119591..d964bdf60d 100755
--- a/perl_exp.SH
+++ b/perl_exp.SH
@@ -1,19 +1,37 @@
#!/bin/sh
-
+#
# Written: Nov 1994 Wayne Scott (wscott@ichips.intel.com)
-
+#
# Create the export list for perl.
# Needed by AIX to do dynamic linking.
-
-# NOTE: If you're using 'old_embed.pl', don't use this script!
-# Use 'old_perl_exp.SH' instead.
-
+#
# This simple program relys on 'global.sym' being up to date
# with all of the global symbols that a dynamicly link library
# might want to access.
+#
+# Most symbols have a Perl_ prefix because that's what embed.h sticks
+# in front of them. Variations depend on binary compatibility with
+# Perl 5.003.
+#
-# All symbols have a Perl_ prefix because that's what embed.h
-# sticks in front of them.
+case $CONFIG in
+'')
+ if test -f config.sh; then TOP=.;
+ elif test -f ../config.sh; then TOP=..;
+ elif test -f ../../config.sh; then TOP=../..;
+ elif test -f ../../../config.sh; then TOP=../../..;
+ elif test -f ../../../../config.sh; then TOP=../../../..;
+ else
+ echo "Can't find config.sh."; exit 1
+ fi
+ . $TOP/config.sh
+ ;;
+esac
+: This forces SH files to create target in same directory as SH file.
+: This is so that make depend always knows where to find SH derivatives.
+case "$0" in
+*/*) cd `expr X$0 : 'X\(.*\)/'` ;;
+esac
echo "Extracting perl.exp"
@@ -22,25 +40,31 @@ echo "#!" > perl.exp
case "$bincompat3" in
y*)
- global=/tmp/exp$$g
- interp=/tmp/exp$$i
- compat3=/tmp/exp$$c
- trap 'rm -f $global $interp $compat3' 0
- trap 'exit 1' 1 2 3 13 15
- grep '^[A-Za-z]' global.sym | sort >$global
- grep '^[A-Za-z]' interp.sym | sort >$interp
- grep '^[A-Za-z]' compat3.sym | sort >$compat3
- comm -23 $global $compat3 | sed 's/^/Perl_/p' >> perl.exp
- comm -12 $global $compat3 >> perl.exp
- comm -12 $interp $compat3 | sed 's/^/Perl_/p' >> perl.exp
- comm -23 $interp $compat3 >> perl.exp
+ (
+ global=/tmp/exp$$g
+ interp=/tmp/exp$$i
+ compat3=/tmp/exp$$c
+ trap 'rm -f $global $interp $compat3' 0
+ trap 'exit 1' 1 2 3 13 15
+ grep '^[A-Za-z]' global.sym | sort >$global
+ grep '^[A-Za-z]' interp.sym | sort >$interp
+ grep '^[A-Za-z]' compat3.sym | sort >$compat3
+ comm -23 $global $compat3 | sed 's/^/Perl_/' >> perl.exp
+ comm -12 $interp $compat3 | sed 's/^/Perl_/' >> perl.exp
+ comm -12 $global $compat3 >> perl.exp
+ comm -23 $interp $compat3 >> perl.exp
+ )
;;
*)
sed -n '/^[A-Za-z]/ s/^/Perl_/p' global.sym interp.sym >> perl.exp
;;
esac
-# extra globals not included above.
+#
+# Extra globals not included above (including a few that might
+# not actually be defined, but there's no harm in that).
+#
+
cat <<END >> perl.exp
perl_init_i18nl10n
perl_init_i18nl14n
@@ -64,4 +88,12 @@ perl_call_pv
perl_call_method
perl_call_sv
perl_requirepv
+Mymalloc
+Mycalloc
+Myremalloc
+Myfree
+Perl_malloc
+Perl_calloc
+Perl_realloc
+Perl_free
END